Type: Package
Package: natcpp
Title: Fast C++ Primitives for the 'NeuroAnatomy Toolbox'
Version: 0.2
Authors@R: 
    person(given = "Gregory",
           family = "Jefferis",
           role = c("aut", "cre"),
           email = "jefferis@gmail.com",
           comment = c(ORCID = "0000-0002-0587-9355"))
Description: Fast functions implemented in C++ via 'Rcpp' to support the
    'NeuroAnatomy Toolbox' ('nat') ecosystem. These functions provide large
    speed-ups for basic manipulation of neuronal skeletons over pure R
    functions found in the 'nat' package. The expectation is that end
    users will not use this package directly, but instead the 'nat'
    package will automatically use routines from this package when it is
    available to enable large performance gains.
License: GPL (>= 3)
URL: https://github.com/natverse/natcpp, https://natverse.org/natcpp/
BugReports: https://github.com/natverse/natcpp/issues
Imports: Rcpp (>= 1.0.6)
Suggests: spelling, testthat (>= 3.0.0)
LinkingTo: Rcpp
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-10-14 21:32:26 UTC; jefferis
Author: Gregory Jefferis [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0587-9355>)
Maintainer: Gregory Jefferis <jefferis@gmail.com>
Repository: CRAN
Date/Publication: 2025-10-14 21:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 20:42:33 UTC; unix
Archs: natcpp.so.dSYM
