# Generated by roxygen2: do not edit by hand

export(c_EdgeListFromSegList)
export(c_ListofMatrixRows)
export(c_coords21dindex)
export(c_ijkpos)
export(c_listlengths)
export(c_seglengths)
export(c_sub2ind)
export(c_topntail)
export(c_topntail_list)
export(c_total_cable)
import(Rcpp)
useDynLib(natcpp, .registration = TRUE)
